relevant_line_comments

Function relevant_line_comments 

pub(crate) fn relevant_line_comments(comment: &Comment) -> Vec<Comment>
The line -> block assist can be invoked from anywhere within a sequence of line comments. relevant_line_comments crawls backwards and forwards finding the complete sequence of comments that will be joined.